// index.js
import { scatterPlot } from './scatterPlot.js';

const csvUrl =
  'https://gist.githubusercontent.com/Rekha-Telkapally/5fd9c2248db0d83914450969765eb54e/raw/add163ad80b6b4495f7713a1fc717d57f291c110/MobilePhones.csv';

const parseDataRow = (d) => {
  d.Sales = +d.Sales;
  d.Units_Sold = +d['Units Sold'];
  return d;
};

const width = window.innerWidth * 0.8;
const height = window.innerHeight * 0.8;

const svg = d3
  .select('#scatterplot')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await d3.csv(csvUrl, parseDataRow);

  // Split the data into two halves for separate visualization.
  const firstHalfData = data.filter(
    (d, i) => i < data.length / 2,
  );
  const secondHalfData = data.filter(
    (d, i) => i >= data.length / 2,
  );

  const scatterPlot1 = scatterPlot()
    .width(width)
    .height(height / 2)
    .xValue((d) => d.Units_Sold) // Change to Units_Sold
    .yValue((d) => d.Sales) // Change to Sales
    .colorValue((d) => d.Brand) // Assuming there's a brand column for color
    .margin({ top: 20, right: 20, bottom: 40, left: 50 })
    .radius(5);

  const scatterPlot2 = scatterPlot()
    .width(width)
    .height(height / 2)
    .xValue((d) => d.Units_Sold) // Change to Units_Sold
    .yValue((d) => d.Sales) // Change to Sales
    .colorValue((d) => d.Brand) // Assuming there's a brand column for color
    .margin({ top: 20, right: 20, bottom: 40, left: 50 })
    .radius(5);

  let currentPlot = 1;

  const update = () => {
    // Remove all existing elements in the SVG to prepare for the new plots.
    svg.selectAll('*').remove();

    // Conditional logic to switch between plot1 and plot2.
    if (currentPlot === 1) {
      scatterPlot1.data(firstHalfData);
      svg.call(scatterPlot1);
      currentPlot = 2;
    } else {
      scatterPlot2.data(secondHalfData);
      svg.call(scatterPlot2);
      currentPlot = 1;
    }
  };

  update();

  // Set an interval to automatically update the plot every 5 seconds.
  setInterval(update, 5000);
};

main();
