// scatterplot.js
import {
  scaleLinear,
  scaleOrdinal,
  extent,
  axisLeft,
  axisBottom,
  select,
  schemeCategory10,
} from 'd3';

export const scatterPlot = () => {
  let width, height, data, xValue, yValue, colorValue;
  let margin = { top: 10, right: 30, bottom: 50, left: 60 };
  let radius = 5;

  const my = (selection) => {
    const colorScale = scaleOrdinal()
      .domain(data.map(colorValue))
      .range(schemeCategory10);

    const xScale = scaleLinear()
      .domain(extent(data, xValue))
      .nice()
      .range([margin.left, width - margin.right]);

    const yScale = scaleLinear()
      .domain(extent(data, yValue))
      .nice()
      .range([height - margin.bottom, margin.top]);

    selection
      .selectAll('circle')
      .data(data)
      .join('circle')
      .attr('cx', (d) => xScale(xValue(d)))
      .attr('cy', (d) => yScale(yValue(d)))
      .attr('r', radius)
      .attr('fill', (d) => colorScale(colorValue(d)));

    selection
      .append('g')
      .attr('transform', `translate(${margin.left},0)`)
      .call(axisLeft(yScale))
      .attr('font-size', '12px');

    selection
      .append('text')
      .attr('text-anchor', 'middle')
      .attr(
        'transform',
        `translate(${margin.left * 0.4}, ${height / 2}) rotate(-90)`,
      )
      .text('Sales');

    selection
      .append('g')
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`,
      )
      .call(axisBottom(xScale))
      .attr('font-size', '12px');

    selection
      .append('text')
      .attr('text-anchor', 'middle')
      .attr('x', width / 2)
      .attr('y', height - margin.bottom * 0.2)
      .text('Units Sold');
  };

  my.width = function (_) {
    return arguments.length ? ((width = +_), my) : width;
  };
  my.height = function (_) {
    return arguments.length ? ((height = +_), my) : height;
  };
  my.data = function (_) {
    return arguments.length ? ((data = _), my) : data;
  };
  my.xValue = function (_) {
    return arguments.length ? ((xValue = _), my) : xValue;
  };
  my.yValue = function (_) {
    return arguments.length ? ((yValue = _), my) : yValue;
  };
  my.colorValue = function (_) {
    return arguments.length
      ? ((colorValue = _), my)
      : colorValue;
  };
  my.margin = function (_) {
    return arguments.length
      ? ((margin = { ...margin, ..._ }), my)
      : margin;
  };
  my.radius = function (_) {
    return arguments.length ? ((radius = +_), my) : radius;
  };

  return my;
};
